/********************************************************************************
 * Copyright (C) 2018 TypeFox and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
import { DisposableCollection, Emitter, Event, MessageService } from '@theia/core';
import { FileSystem } from '@theia/filesystem/lib/common';
import { LocalStorageService } from '@theia/core/lib/browser';
import { WorkspaceService } from '@theia/workspace/lib/browser/workspace-service';
import { GitRepositoryTracker } from './git-repository-tracker';
import { ProblemManager } from '@theia/markers/lib/browser/problem/problem-manager';
import { Feature, GAD, FeatureVersion } from '../common';
import { AuthService } from '@quarks/auth-extension/lib/browser/auth-service';
export interface BuildEvent {
    type: 'start' | 'end';
    result?: 'ok' | 'nok';
    details?: any;
}
export interface DeployEvent {
    type: 'start' | 'end';
    result?: 'ok' | 'nok';
    details?: any;
}
export declare class GADService {
    protected readonly gitRepositoryTracker: GitRepositoryTracker;
    protected readonly storageService: LocalStorageService;
    protected readonly fileSystem: FileSystem;
    protected readonly workspaceService: WorkspaceService;
    protected readonly gad: GAD;
    protected readonly authService: AuthService;
    protected readonly messageService: MessageService;
    protected readonly problemManager: ProblemManager;
    protected _selectedFeature?: Feature;
    protected _workspaceFeatures?: Array<Feature>;
    protected toDispose: DisposableCollection;
    protected readonly selectedFeatureStorageKey: string;
    protected readonly workspaceFeaturesStorageKey: string;
    protected readonly onFeatureChangeEmitter: Emitter<Feature>;
    readonly onFeatureChange: Event<Feature>;
    protected readonly onBuildEmitter: Emitter<BuildEvent>;
    readonly onBuild: Event<BuildEvent>;
    protected readonly onDeployEmitter: Emitter<DeployEvent>;
    readonly onDeploy: Event<DeployEvent>;
    protected deploying: boolean;
    protected building: boolean;
    isDeploying(): boolean;
    isBuilding(): boolean;
    constructor(gitRepositoryTracker: GitRepositoryTracker, storageService: LocalStorageService, fileSystem: FileSystem, workspaceService: WorkspaceService, gad: GAD, authService: AuthService, messageService: MessageService, problemManager: ProblemManager);
    protected init(): Promise<void>;
    protected refreshFeatures(): Promise<void>;
    protected loadFeature(uri: string): Promise<Feature>;
    protected fireFeatureChange(feature: Feature): void;
    lsFeatureVersions(id: string): Promise<FeatureVersion[]>;
    buildFeature(): Promise<void>;
    deployFeature(): Promise<void>;
    readonly onFeatureChangeEvent: Event<Feature>;
    readonly selectedFeature: Feature;
}
//# sourceMappingURL=gad-service.d.ts.map