/********************************************************************************
 * Copyright (C) 2017 TypeFox and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
import { Git, Repository } from '../common';
import { WorkspaceService } from '@theia/workspace/lib/browser/workspace-service';
import { FileSystem } from '@theia/filesystem/lib/common';
import { Event, Emitter } from '@theia/core';
import { LocalStorageService } from '@theia/core/lib/browser';
import URI from '@theia/core/lib/common/uri';
export interface GitRefreshOptions {
    readonly maxCount: number;
}
export declare class GitRepositoryProvider {
    protected readonly git: Git;
    protected readonly workspaceService: WorkspaceService;
    protected readonly fileSystem: FileSystem;
    protected readonly storageService: LocalStorageService;
    protected _selectedRepository: Repository | undefined;
    protected _allRepositories?: Repository[];
    protected readonly onDidChangeRepositoryEmitter: Emitter<Repository | undefined>;
    protected readonly selectedRepoStorageKey: string;
    protected readonly allRepoStorageKey: string;
    constructor(git: Git, workspaceService: WorkspaceService, fileSystem: FileSystem, storageService: LocalStorageService);
    protected initialize(): Promise<void>;
    /**
     * Returns with the previously selected repository, or if no repository has been selected yet,
     * it picks the first available repository from the backend and sets it as the selected one and returns with that.
     * If no repositories are available, returns `undefined`.
     */
    /**
    * Sets or un-sets the repository.
    */
    selectedRepository: Repository | undefined;
    readonly onDidChangeRepository: Event<Repository | undefined>;
    protected fireDidChangeRepository(): void;
    /**
     * Returns with all know repositories.
     */
    readonly allRepositories: Repository[];
    findRepository(uri: URI): Repository | undefined;
    findRepositoryOrSelected(arg: URI | string | {
        uri?: string | URI;
    } | undefined): Repository | undefined;
    refresh(options?: GitRefreshOptions): Promise<void>;
    protected exists(repository: Repository): boolean;
}
//# sourceMappingURL=git-repository-provider.d.ts.map