/********************************************************************************
 * Copyright (C) 2018 TypeFox and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
import { Git, Repository, WorkingDirectoryStatus } from '../common';
import { Event, Emitter, DisposableCollection } from '@theia/core';
import { GitRepositoryProvider } from './git-repository-provider';
import { GitWatcher, GitStatusChangeEvent } from '../common/git-watcher';
import URI from '@theia/core/lib/common/uri';
/**
 * The repository tracker watches the selected repository for status changes. It provides a convenient way to listen on status updates.
 */
export declare class GitRepositoryTracker {
    protected readonly git: Git;
    protected readonly repositoryProvider: GitRepositoryProvider;
    protected readonly gitWatcher: GitWatcher;
    protected toDispose: DisposableCollection;
    protected workingDirectoryStatus: WorkingDirectoryStatus | undefined;
    protected readonly onGitEventEmitter: Emitter<GitStatusChangeEvent>;
    constructor(git: Git, repositoryProvider: GitRepositoryProvider, gitWatcher: GitWatcher);
    protected init(): Promise<void>;
    /**
     * Returns the selected repository, or `undefined` if no repositories are available.
     */
    readonly selectedRepository: Repository | undefined;
    /**
     * Returns all known repositories.
     */
    readonly allRepositories: Repository[];
    /**
     * Returns the last known status of the selected respository, or `undefined` if no repositories are available.
     */
    readonly selectedRepositoryStatus: WorkingDirectoryStatus | undefined;
    /**
     * Emits when the selected repository has changed.
     */
    readonly onDidChangeRepository: Event<Repository | undefined>;
    /**
     * Emits when status has changed in the selected repository.
     */
    readonly onGitEvent: Event<GitStatusChangeEvent>;
    getPath(uri: URI): string | undefined;
    getUri(path: string): URI | undefined;
    readonly repositoryUri: URI | undefined;
}
//# sourceMappingURL=git-repository-tracker.d.ts.map