/********************************************************************************
 * Copyright (C) 2017 TypeFox and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
/// <reference types="node" />
import { Disposable, Event, Emitter, ILogger, DisposableCollection } from '@theia/core';
import { Git, Repository, WorkingDirectoryStatus } from '../common';
import { GitStatusChangeEvent } from '../common/git-watcher';
export declare const GitRepositoryWatcherFactory: unique symbol;
export declare type GitRepositoryWatcherFactory = (options: GitRepositoryWatcherOptions) => GitRepositoryWatcher;
export declare class GitRepositoryWatcherOptions {
    readonly repository: Repository;
}
export declare class GitRepositoryWatcher implements Disposable {
    protected readonly onStatusChangedEmitter: Emitter<GitStatusChangeEvent>;
    readonly onStatusChanged: Event<GitStatusChangeEvent>;
    protected readonly git: Git;
    protected readonly logger: ILogger;
    protected readonly options: GitRepositoryWatcherOptions;
    protected readonly toDispose: DisposableCollection;
    watch(): void;
    sync(): void;
    dispose(): void;
    protected initial: boolean;
    protected watchTimer: NodeJS.Timer | undefined;
    protected schedule(initial?: boolean, delay?: number): void;
    protected clear(): void;
    protected status: WorkingDirectoryStatus | undefined;
    protected syncStatus(initial?: boolean): Promise<boolean>;
}
//# sourceMappingURL=git-repository-watcher.d.ts.map