/********************************************************************************
 * Copyright (C) 2017 TypeFox and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/

import { Disposable } from '@theia/core';
import { User } from '@quarks/auth-extension/lib/common';

/**
 * The WS endpoint path to the Gad service.
 */
export const GADPath = '/services/gad';

export const GAD = Symbol('GAD');

export interface Feature {

    readonly id?: string;

    readonly name?: string;

    readonly version?: string;

    readonly localUri?: string;

    readonly context?: {
        id: string
    }

    readonly allowNewVersion?: boolean;

    readonly allowNewBugfix?: boolean;

    status?: any;
}

export interface FeatureVersion {

    readonly version?: string;

    readonly description?: string;

    readonly status?: 'closed' | 'dev';

    readonly uri?: string;

    readonly type?: 'branch' | 'tag';

    readonly ref?: string;
}

export interface Environment {
    readonly id?: string;

    readonly name?: string;

    readonly type?: string;
}

export interface Result {
    readonly status: 'ok' | 'nok';

    readonly details?: any;
}

export interface GAD extends Disposable {

    lsFeatureVersions(id: string): Promise<FeatureVersion[]>;

    lsEnvironment(contextId: string): Promise<Environment[]>

    getFeature(uri: string): Promise<Feature>;

    newFeature(feature: Feature, user: User): Promise<Result>;

    importFeature(feature: Feature, user: User): Promise<Result>;

    buildFeature(feature: Feature, environment: Environment, user: User, simulate?: boolean): Promise<Result>;

    provisionFeature(feature: Feature, environment: Environment, user: User): Promise<Result>;
}
